Learn R Programming

colorDF (version 0.1.4)

is.colorDF: Test whether an object has the class of colorDF

Description

Test whether an object has the class of colorDF

Usage

is.colorDF(x)

Arguments

x

a data frame like object

Value

TRUE if the object is of colorDF class