Learn R Programming

colorDF (version 0.1.4)

term_boxplot: Boxplot in a terminal

Description

Show a boxplot using characters in the terminal window

Usage

term_boxplot(formula, data = NULL, width = getOption("width"))

Arguments

formula

a formula

data

data frame or matrix

width

width of the boxplot in characters

Value

invisibly return the color summary data frame used to draw the boxplot

Examples

Run this code
# NOT RUN {
term_boxplot(mpg ~ cyl, data=mtcars)
term_boxplot(Sepal.Length ~ Species, data=iris, width=70)
# }

Run the code above in your browser using DataLab